import React from "react";
import styled from "styled-components";
import ClickToCopy from "../../util/ClickToCopy";
import Button from "../../util/Button";
import usePlayerScores from "../../../hooks/usePlayerScores";

const useTopScorer = (gameId, roundNum) => {
  const scores = usePlayerScores(gameId);
  const top = { topPlayer: null, topScore: null };

  if (scores === null) {
    return top;
  }

  scores
    .filter(({ guesses }) => guesses[roundNum] && guesses[roundNum].score)
    .forEach(({ name, guesses }) => {
      const score = guesses[roundNum].score;
      if (top.topScore === null || score > top.topScore) {
        top.topPlayer = name;
        top.topScore = score;
      }
    });

  return top;
}

const Container = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-between;
  align-items: center;

  @media only screen and (min-width: 600px) {
    margin-left: 10px;
    align-items: flex-start;
  }
`

const TimedOut = styled.span`
  color: red;
`

const NextButton = styled(Button)`
  margin-top: 5px;
  padding: 1em;
`

export default ({
  gameId,
  selectedPoint,
  targetPoint,
  roundNum,
  score,
  totalScore,
  onNext
}) => {
  const { topPlayer, topScore } = useTopScorer(gameId, roundNum);

  return (
    <Container>
      {selectedPoint
        ? <span>
            You selected: <ClickToCopy text={`${selectedPoint.lat}, ${selectedPoint.lng}`}/>
          </span>
        : <TimedOut>Timed out!</TimedOut>
      }
      <span>Target: <ClickToCopy text={`${targetPoint.lat}, ${targetPoint.lng}`}/></span>
      <span>Score For Round {roundNum}: {score}</span>
      <span>Running Total Score: {totalScore}</span>
      {topPlayer ? <span className="round-summary__top-score">Current best is {topPlayer} with {topScore}</span> : null}
      <NextButton onClick={onNext}>{roundNum === "5" ? "View Summary" : "Next Round"}</NextButton>
    </Container>
  );
}
